@@ -34,6 +34,7 @@ receive
 time
 cond-expand
 define-cond-expand-feature
+case-lambda
 letrec*
 
 ;; global variable
@@ -90,6 +91,7 @@ cfun-conversion-exception-code
 cfun-conversion-exception-message
 cfun-conversion-exception-procedure
 cfun-conversion-exception?
+circular-list
 clear-bit-field
 close-port
 command-line
@@ -103,6 +105,7 @@ condition-variable-specific-set!
 condition-variable?
 configure-command-string
 conjugate
+cons*
 console-port
 continuation-capture
 continuation-graft
@@ -144,6 +147,7 @@ display-procedure-environment
 divide-by-zero-exception-arguments
 divide-by-zero-exception-procedure
 divide-by-zero-exception?
+drop
 eq?-hash
 equal?-hash
 eqv?-hash
@@ -165,6 +169,7 @@ f32vector-copy
 f32vector-fill!
 f32vector-length
 f32vector-ref
+f32vector-set
 f32vector-set!
 f32vector-shrink!
 f32vector?
@@ -175,6 +180,7 @@ f64vector-copy
 f64vector-fill!
 f64vector-length
 f64vector-ref
+f64vector-set
 f64vector-set!
 f64vector-shrink!
 f64vector?
@@ -264,6 +270,8 @@ fltan
 fltanh
 fltruncate
 flzero?
+fold
+fold-right
 force-output
 foreign-address
 foreign-release!
@@ -359,6 +367,7 @@ integer-sqrt
 invalid-hash-number-exception-arguments
 invalid-hash-number-exception-procedure
 invalid-hash-number-exception?
+iota
 join-timeout-exception-arguments
 join-timeout-exception-procedure
 join-timeout-exception?
@@ -368,6 +377,8 @@ keyword-expected-exception-procedure
 keyword-expected-exception?
 keyword-hash
 keyword?
+last
+last-pair
 link-flat
 link-incremental
 list->f32vector
@@ -381,6 +392,10 @@ list->u16vector
 list->u32vector
 list->u64vector
 list->u8vector
+list-copy
+list-set
+list-set!
+list-tabulate
 mailbox-receive-timeout-exception-arguments
 mailbox-receive-timeout-exception-procedure
 mailbox-receive-timeout-exception?
@@ -388,6 +403,7 @@ main
 make-condition-variable
 make-f32vector
 make-f64vector
+make-list
 make-mutex
 make-parameter
 make-random-source
@@ -485,8 +501,8 @@ path-strip-extension
 path-strip-trailing-directory-separator
 path-strip-volume
 path-volume
-port-settings-set!
 port-io-exception-handler-set!
+port-settings-set!
 port?
 pp
 pretty-print
@@ -557,6 +573,7 @@ repl-output-port
 repl-result-history-max-length-set!
 repl-result-history-ref
 replace-bit-field
+reverse!
 rpc-remote-error-exception-arguments
 rpc-remote-error-exception-message
 rpc-remote-error-exception-procedure
@@ -568,6 +585,7 @@ s16vector-copy
 s16vector-fill!
 s16vector-length
 s16vector-ref
+s16vector-set
 s16vector-set!
 s16vector-shrink!
 s16vector?
@@ -578,6 +596,7 @@ s32vector-copy
 s32vector-fill!
 s32vector-length
 s32vector-ref
+s32vector-set
 s32vector-set!
 s32vector-shrink!
 s32vector?
@@ -588,6 +607,7 @@ s64vector-copy
 s64vector-fill!
 s64vector-length
 s64vector-ref
+s64vector-set
 s64vector-set!
 s64vector-shrink!
 s64vector?
@@ -598,6 +618,7 @@ s8vector-copy
 s8vector-fill!
 s8vector-length
 s8vector-ref
+s8vector-set
 s8vector-set!
 s8vector-shrink!
 s8vector?
@@ -709,6 +730,7 @@ string->keyword
 string->uninterned-keyword
 string->uninterned-symbol
 string-ci=?-hash
+string-set
 string-shrink!
 string=?-hash
 subf32vector
@@ -762,6 +784,7 @@ table-ref
 table-search
 table-set!
 table?
+take
 tanh
 tcp-client-local-socket-info
 tcp-client-peer-socket-info
@@ -781,9 +804,9 @@ thread-group->thread-list
 thread-group->thread-vector
 thread-group-name
 thread-group-parent
+thread-group-resume!
 thread-group-specific
 thread-group-specific-set!
-thread-group-resume!
 thread-group-suspend!
 thread-group-terminate!
 thread-group?
@@ -848,6 +871,7 @@ u16vector-copy
 u16vector-fill!
 u16vector-length
 u16vector-ref
+u16vector-set
 u16vector-set!
 u16vector-shrink!
 u16vector?
@@ -858,6 +882,7 @@ u32vector-copy
 u32vector-fill!
 u32vector-length
 u32vector-ref
+u32vector-set
 u32vector-set!
 u32vector-shrink!
 u32vector?
@@ -868,6 +893,7 @@ u64vector-copy
 u64vector-fill!
 u64vector-length
 u64vector-ref
+u64vector-set
 u64vector-set!
 u64vector-shrink!
 u64vector?
@@ -879,6 +905,7 @@ u8vector-copy
 u8vector-fill!
 u8vector-length
 u8vector-ref
+u8vector-set
 u8vector-set!
 u8vector-shrink!
 u8vector?
@@ -932,6 +959,7 @@ vector-append
 vector-cas!
 vector-copy
 vector-inc!
+vector-set
 vector-shrink!
 void
 will-execute!
@@ -956,6 +984,7 @@ wrong-number-of-arguments-exception-arguments
 wrong-number-of-arguments-exception-procedure
 wrong-number-of-arguments-exception?
 wrong-processor-c-return-exception?
+xcons
 
 ))
 
